==> modonomicon-1.20.1-fabric-1.79.1-sources.jar: com/klikli_dev/modonomicon/client/render/page/PageRendererRegistry.java <==
/*
 * SPDX-FileCopyrightText: 2022 klikli-dev
 *
 * SPDX-License-Identifier: MIT
 */

package com.klikli_dev.modonomicon.client.render.page;

import com.klikli_dev.modonomicon.api.ModonomiconConstants.Data.Page;
import com.klikli_dev.modonomicon.book.page.*;
import com.klikli_dev.modonomicon.fluid.FluidHolder;
import java.util.Collection;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.ConcurrentHashMap;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_2960;
import net.minecraft.class_3611;

public class PageRendererRegistry {
    static final Set<class_1792> ITEMS_NOT_TO_RENDER = ConcurrentHashMap.newKeySet();
    static final Set<class_3611> FLUIDS_NOT_TO_RENDER = ConcurrentHashMap.newKeySet();
    private static final Map<class_2960, PageRendererFactory> pageRenderers = new ConcurrentHashMap<>();

    /**
     * Call from client setup
     */
    public static void registerPageRenderers() {
        registerDefaultPageRenderers();
    }

    private static void registerDefaultPageRenderers() {
        registerPageRenderer(Page.TEXT, p -> new BookTextPageRenderer((BookTextPage) p));
        registerPageRenderer(Page.MULTIBLOCK, p -> new BookMultiblockPageRenderer((BookMultiblockPage) p));
        registerPageRenderer(Page.CRAFTING_RECIPE, p -> new BookCraftingRecipePageRenderer((BookCraftingRecipePage) p));
        registerPageRenderer(Page.SMELTING_RECIPE, p -> new BookProcessingRecipePageRenderer<>((BookSmeltingRecipePage) p) {
        });
        registerPageRenderer(Page.SMOKING_RECIPE, p -> new BookProcessingRecipePageRenderer<>((BookSmokingRecipePage) p) {
        });
        registerPageRenderer(Page.CAMPFIRE_COOKING_RECIPE, p -> new BookProcessingRecipePageRenderer<>((BookCampfireCookingRecipePage) p) {
        });
        registerPageRenderer(Page.BLASTING_RECIPE, p -> new BookProcessingRecipePageRenderer<>((BookBlastingRecipePage) p) {
        });
        registerPageRenderer(Page.STONECUTTING_RECIPE, p -> new BookProcessingRecipePageRenderer<>((BookStonecuttingRecipePage) p) {
        });
        registerPageRenderer(Page.SMITHING_RECIPE, p -> new BookSmithingRecipePageRenderer((BookSmithingRecipePage) p) {
        });
        registerPageRenderer(Page.SPOTLIGHT, p -> new BookSpotlightPageRenderer((BookSpotlightPage) p) {
        });
        registerPageRenderer(Page.EMPTY, p -> new BookEmptyPageRenderer((BookEmptyPage) p) {
        });
        registerPageRenderer(Page.ENTITY, p -> new BookEntityPageRenderer((BookEntityPage) p) {
        });
        registerPageRenderer(Page.IMAGE, p -> new BookImagePageRenderer((BookImagePage) p) {
        });
    }

    /**
     * Call from client setup
     */
    public static void registerPageRenderer(class_2960 id, PageRendererFactory factory) {
        pageRenderers.put(id, factory);
    }

    public static PageRendererFactory getPageRenderer(class_2960 id) {
        var renderer = pageRenderers.get(id);
        if (renderer == null) {
            throw new IllegalArgumentException("No page renderer registered for page type " + id);
        }
        return renderer;
    }

    /**
     * Any items registered here, will not be rendered by the renderIngredient / renderItemStacks / renderItemStack methods.
     * Can be called at any time.
     */
    public static void registerItemStackNotToRender(class_1799 stack) {
        ITEMS_NOT_TO_RENDER.add(stack.method_7909());
    }

    /**
     * Any fluids registered here, will not be rendered by the renderFluidStacks / renderFluidStack methods.
     * Can be called at any time.
     */
    public static void registerFluidStackNotToRender(FluidHolder stack) {
        FLUIDS_NOT_TO_RENDER.add(stack.getFluid());
    }

    /**
     * Returns false, if the given stack should not be rendered in the book, e.g. in recipes.
     */
    public static boolean isRenderable(class_1799 stack) {
        return !ITEMS_NOT_TO_RENDER.contains(stack.method_7909());
    }

    /**
     * Returns false, if the given stack should not be rendered in the book, e.g. in recipes.
     */
    public static boolean isRenderable(FluidHolder stack) {
        return !FLUIDS_NOT_TO_RENDER.contains(stack.getFluid());
    }

    /**
     * Returns only those stacks in the list, that should be rendered in the book, e.g. in recipes.
     */
    public static List<class_1799> filterRenderableItemStacks(Collection<class_1799> stacks) {
        return stacks.stream().filter(stack -> !ITEMS_NOT_TO_RENDER.contains(stack.method_7909())).toList();
    }

    /**
     * Returns only those stacks in the list, that should be rendered in the book, e.g. in recipes.
     */
    public static List<FluidHolder> filterRenderableFluidStacks(Collection<FluidHolder> stacks) {
        return stacks.stream().filter(stack -> !FLUIDS_NOT_TO_RENDER.contains(stack.getFluid())).toList();
    }
}

==> modonomicon-1.21.10-fabric-1.119.0-sources.jar: com/klikli_dev/modonomicon/client/render/page/PageRendererRegistry.java <==
/*
 * SPDX-FileCopyrightText: 2022 klikli-dev
 *
 * SPDX-License-Identifier: MIT
 */

package com.klikli_dev.modonomicon.client.render.page;

import com.klikli_dev.modonomicon.api.ModonomiconConstants.Data.Page;
import com.klikli_dev.modonomicon.book.page.*;
import com.klikli_dev.modonomicon.fluid.FluidHolder;
import it.unimi.dsi.fastutil.objects.Object2ObjectMaps;
import it.unimi.dsi.fastutil.objects.Object2ObjectOpenHashMap;
import it.unimi.dsi.fastutil.objects.ObjectOpenHashSet;
import it.unimi.dsi.fastutil.objects.ObjectSets;
import java.util.Collection;
import java.util.List;
import java.util.Map;
import java.util.Set;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_2960;
import net.minecraft.class_3611;

public class PageRendererRegistry {
    static final Set<class_1792> ITEMS_NOT_TO_RENDER = ObjectSets.synchronize(new ObjectOpenHashSet<>());
    static final Set<class_3611> FLUIDS_NOT_TO_RENDER = ObjectSets.synchronize(new ObjectOpenHashSet<>());
    private static final Map<class_2960, PageRendererFactory> pageRenderers = Object2ObjectMaps.synchronize(new Object2ObjectOpenHashMap<>());

    /**
     * Call from client setup
     */
    public static void registerPageRenderers() {
        registerDefaultPageRenderers();
    }

    private static void registerDefaultPageRenderers() {
        registerPageRenderer(Page.TEXT, p -> new BookTextPageRenderer((BookTextPage) p));
        registerPageRenderer(Page.MULTIBLOCK, p -> new BookMultiblockPageRenderer((BookMultiblockPage) p));
        registerPageRenderer(Page.CRAFTING_RECIPE, p -> new BookCraftingRecipePageRenderer((BookCraftingRecipePage) p));
        registerPageRenderer(Page.SMELTING_RECIPE, p -> new BookProcessingRecipePageRenderer<>((BookSmeltingRecipePage) p) {
        });
        registerPageRenderer(Page.SMOKING_RECIPE, p -> new BookProcessingRecipePageRenderer<>((BookSmokingRecipePage) p) {
        });
        registerPageRenderer(Page.CAMPFIRE_COOKING_RECIPE, p -> new BookProcessingRecipePageRenderer<>((BookCampfireCookingRecipePage) p) {
        });
        registerPageRenderer(Page.BLASTING_RECIPE, p -> new BookProcessingRecipePageRenderer<>((BookBlastingRecipePage) p) {
        });
        registerPageRenderer(Page.STONECUTTING_RECIPE, p -> new BookProcessingRecipePageRenderer<>((BookStonecuttingRecipePage) p) {
        });
        registerPageRenderer(Page.SMITHING_RECIPE, p -> new BookSmithingRecipePageRenderer((BookSmithingRecipePage) p) {
        });
        registerPageRenderer(Page.SPOTLIGHT, p -> new BookSpotlightPageRenderer((BookSpotlightPage) p) {
        });
        registerPageRenderer(Page.EMPTY, p -> new BookEmptyPageRenderer((BookEmptyPage) p) {
        });
        registerPageRenderer(Page.ENTITY, p -> new BookEntityPageRenderer((BookEntityPage) p) {
        });
        registerPageRenderer(Page.IMAGE, p -> new BookImagePageRenderer((BookImagePage) p) {
        });
    }

    /**
     * Call from client setup
     */
    public static void registerPageRenderer(class_2960 id, PageRendererFactory factory) {
        pageRenderers.put(id, factory);
    }

    public static PageRendererFactory getPageRenderer(class_2960 id) {
        var renderer = pageRenderers.get(id);
        if (renderer == null) {
            throw new IllegalArgumentException("No page renderer registered for page type " + id);
        }
        return renderer;
    }

    /**
     * Any items registered here, will not be rendered by the renderIngredient / renderItemStacks / renderItemStack methods.
     * Can be called at any time.
     */
    public static void registerItemStackNotToRender(class_1799 stack) {
        ITEMS_NOT_TO_RENDER.add(stack.method_7909());
    }

    /**
     * Any fluids registered here, will not be rendered by the renderFluidStacks / renderFluidStack methods.
     * Can be called at any time.
     */
    public static void registerFluidStackNotToRender(FluidHolder stack) {
        FLUIDS_NOT_TO_RENDER.add(stack.getFluid().comp_349());
    }

    /**
     * Returns false, if the given stack should not be rendered in the book, e.g. in recipes.
     */
    public static boolean isRenderable(class_1799 stack) {
        return !ITEMS_NOT_TO_RENDER.contains(stack.method_7909());
    }

    /**
     * Returns false, if the given stack should not be rendered in the book, e.g. in recipes.
     */
    public static boolean isRenderable(FluidHolder stack) {
        return !FLUIDS_NOT_TO_RENDER.contains(stack.getFluid());
    }

    /**
     * Returns only those stacks in the list, that should be rendered in the book, e.g. in recipes.
     */
    public static List<class_1799> filterRenderableItemStacks(Collection<class_1799> stacks) {
        return stacks.stream().filter(stack -> !ITEMS_NOT_TO_RENDER.contains(stack.method_7909())).toList();
    }

    /**
     * Returns only those stacks in the list, that should be rendered in the book, e.g. in recipes.
     */
    public static List<FluidHolder> filterRenderableFluidStacks(Collection<FluidHolder> stacks) {
        return stacks.stream().filter(stack -> !FLUIDS_NOT_TO_RENDER.contains(stack.getFluid())).toList();
    }
}
